| gripsYR2 | R Documentation |
Modified recruitment data from the second year of the GRIPS study. This dataset includes the number or participants recruited for each calendar date during active recruitment periods.
gripsYR2
A data frame with 292 observations of 2 variables
| [,1] | ScreenDt | character | Calendar date of the screening process for recruitment in the study |
| [,2] | Enrolled | integer | Number of new subjects enrolled in the study on that date |
Villasante-Tezanos A, Kuo Y, Kurinec C, Li Y, Yu X (2024). "A non-parametric approach to predict the recruitment for randomized clinical trials: an example in elderly inpatient settings." BMC medical research methodology, 24, 189. ISSN 1471-2288, https://pubmed.ncbi.nlm.nih.gov/39210285/.
Other Links:
GetDistance(),
GetWeekPredCI(),
LoadData(),
RCTRecruit-package,
Time2Nsubjects(),
gripsYR1,
gripsYR2Weekly,
plot.RCTPredCI()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.