| gripsYR2Weekly | R Documentation |
Modified recruitment data from the second year of the GRIPS study, aggregated by calendar week.
gripsYR2Weekly
A data frame with 52 observations of 4 variables
| [,1] | week | double | Calendar week |
| [,2] | year | double | Calendar year |
| [,3] | enrolled | integer | Number of people enrolled that week |
| [,4] | activeDays | integer | Number of days in that week when recruitment was active |
Villasante-Tezanos A, Kuo Y, Kurinec C, Li Y, Yu X (2024). "A non-parametric approach to predict the recruitment for randomized clinical trials: an example in elderly inpatient settings." BMC medical research methodology, 24, 189. ISSN 1471-2288, https://pubmed.ncbi.nlm.nih.gov/39210285/.
Other Links:
GetDistance(),
GetWeekPredCI(),
LoadData(),
RCTRecruit-package,
Time2Nsubjects(),
gripsYR1,
gripsYR2,
plot.RCTPredCI()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.